@@ -21,8 +21,12 @@ from braintree.customer_gateway import CustomerGateway
 from braintree.customer_search import CustomerSearch
 from braintree.descriptor import Descriptor
 from braintree.disbursement import Disbursement
+from braintree.document_upload import DocumentUpload
+from braintree.document_upload_gateway import DocumentUploadGateway
 from braintree.discount import Discount
 from braintree.discount_gateway import DiscountGateway
+from braintree.dispute import Dispute
+from braintree.dispute_search import DisputeSearch
 from braintree.environment import Environment
 from braintree.error_codes import ErrorCodes
 from braintree.error_result import ErrorResult
@@ -57,6 +61,7 @@ from braintree.transaction import Transaction
 from braintree.transaction_amounts import TransactionAmounts
 from braintree.transaction_details import TransactionDetails
 from braintree.transaction_gateway import TransactionGateway
+from braintree.transaction_line_item import TransactionLineItem
 from braintree.transaction_search import TransactionSearch
 from braintree.transparent_redirect import TransparentRedirect
 from braintree.transparent_redirect_gateway import TransparentRedirectGateway
